'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _minimist = require('minimist');

var _minimist2 = _interopRequireDefault(_minimist);

var _colors = require('colors');

var _colors2 = _interopRequireDefault(_colors);

var _quizGenerator = require('../quiz-generator.js');

var _quizGenerator2 = _interopRequireDefault(_quizGenerator);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; } /* eslint-disable no-console */


exports.default = function () {
  var ref = _asyncToGenerator(function* (args) {
    const argv = (0, _minimist2.default)(args, {
      string: ['material', 'sources', 'sections', 'size', 'instruction', 'sentenceSeparator', 'clauseRegExp', 'wordRegExp', 'wordBoundaryRegExp', 'abbrRegExp'],
      boolean: ['skip-spaces'],
      alias: {
        m: 'material',
        t: 'texts',
        l: 'lemmatized',
        s: 'sections',
        S: 'size'
      },
      default: {
        instruction: 'Write down the meaning of underlined words/phrases.',
        wordRegExp: '[\\w\'-]+' }
    });

    // need for display
    const material = argv.material;
    const sources = argv.sources;
    const sentenceSeparator = argv.sentenceSeparator && new RegExp(argv.sentenceSeparator, 'g');
    const clauseRegExp = argv.clauseRegExp && new RegExp(argv.clauseRegExp, 'g');
    const wordRegExp = argv.wordRegExp && new RegExp(argv.wordRegExp, 'g');
    const wordBoundaryRegExp = argv.wordBoundaryRegExp && new RegExp(argv.wordBoundaryRegExp);
    const abbrRegExp = argv.abbrRegExp && new RegExp(argv.abbrRegExp, 'g');
    const generator = new _quizGenerator2.default({
      material, sources, sentenceSeparator, clauseRegExp, wordRegExp,
      wordBoundaryRegExp, abbrRegExp
    });
    yield generator.init();

    const sections = argv.sections;
    const size = Number(argv.size);
    const questions = yield generator.quiz({ sections, size });

    console.log(_colors2.default.bold(argv.instruction));
    questions.forEach(function (q, i) {
      const blockRegExp = new RegExp(`(${ argv.wordRegExp })(\\s+)?`, 'g');
      let currentWordIndex = 0;

      console.log(`(${ i + 1 })\t` + q.sentence.replace(blockRegExp, function (block, word) {
        let space = arguments.length <= 2 || arguments[2] === undefined ? '' : arguments[2];

        if (q.wordIndexes[0] === currentWordIndex) {
          q.wordIndexes.shift();
          currentWordIndex++;

          if (argv['skip-spaces']) {
            return _colors2.default.underline(word);
          }

          if (q.wordIndexes[0] && q.wordIndexes[0] === currentWordIndex) {
            return _colors2.default.underline(block);
          }

          return _colors2.default.underline(word) + space;
        }

        currentWordIndex++;
        return argv['skip-spaces'] ? word : block;
      }) + `\t(${ q.reference })`);
    });

    console.log(_colors2.default.bold('\nAnswer Keys'));
    questions.forEach(function (q, i) {
      console.log(`(${ i + 1 })\t${ q.answer }`);
    });
  });

  return function (_x) {
    return ref.apply(this, arguments);
  };
}();
//# sourceMappingURL=generate.js.map