'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _mecab = require('../mecab.js');

var _mecab2 = _interopRequireDefault(_mecab);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          * Lemmatizer for Classical Japanese using MeCab
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          */


const MECAB_WORD = 0;
const MECAB_LEMMA = 13;
const mecabHome = _path2.default.join(__dirname, '..', '..', 'vendor', 'mecab');
const mecabPath = _path2.default.join(mecabHome, 'mecab', 'bin', 'mecab');
const rcPath = _path2.default.join(mecabHome, 'unidic-cj', '.mecabrc-cj');
const mecab = new _mecab2.default({ command: `${ mecabPath } --rcfile=${ rcPath }` });

exports.default = function () {
  var ref = _asyncToGenerator(function* (text) {
    const chunks = _lodash2.default.chunk(text.replace(/ /g, '').split(/\n/), 10);
    const lemmatizedChunks = [];

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = chunks[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        const chunk = _step.value;

        const lemmatized = yield Promise.all(chunk.map(function (paragraph) {
          return mecab.parse(paragraph).then(function (results) {
            return results.map(function (parsed) {
              return(
                // '*' means there is no lemma data for this word.
                parsed[MECAB_LEMMA] !== '*' ? parsed[MECAB_LEMMA] : parsed[MECAB_WORD]
              );
            }).join(' ');
          });
        })).then(function (results) {
          return results.join('\n');
        });

        lemmatizedChunks.push(lemmatized);
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    return lemmatizedChunks.join('\n');
  });

  return function (_x) {
    return ref.apply(this, arguments);
  };
}();
//# sourceMappingURL=ojp.js.map