'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var _mecab = require('../mecab.js');

var _mecab2 = _interopRequireDefault(_mecab);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { return step("next", value); }, function (err) { return step("throw", err); }); } } return step("next"); }); }; }

const MECAB_WORD = 0;
const mecabHome = _path2.default.join(__dirname, '..', '..', 'vendor', 'mecab');
const mecabPath = _path2.default.join(mecabHome, 'mecab', 'bin', 'mecab');
const rcPath = _path2.default.join(mecabHome, 'unidic-cj', '.mecabrc-cj');
const mecab = new _mecab2.default({ command: `${ mecabPath } --rcfile=${ rcPath }` });

/**
 * Returns wakachigaki-style sentences.
 */
const wakatsu = (() => {
  var ref = _asyncToGenerator(function* (text) {
    const chunks = _lodash2.default.chunk(text.split(/\n/), 10);
    const results = [];

    var _iteratorNormalCompletion = true;
    var _didIteratorError = false;
    var _iteratorError = undefined;

    try {
      for (var _iterator = chunks[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
        const chunk = _step.value;

        const result = yield Promise.all(chunk.map(function (paragraph) {
          return mecab.parse(paragraph).then(function (parsed) {
            return parsed.map(function (table) {
              return table[MECAB_WORD];
            }).join(' ');
          });
        })).then(function (items) {
          return items.join('\n');
        });

        results.push(result);
      }
    } catch (err) {
      _didIteratorError = true;
      _iteratorError = err;
    } finally {
      try {
        if (!_iteratorNormalCompletion && _iterator.return) {
          _iterator.return();
        }
      } finally {
        if (_didIteratorError) {
          throw _iteratorError;
        }
      }
    }

    return results.join('\n');
  }),
      _this = undefined;

  return function wakatsu(_x) {
    return ref.apply(_this, arguments);
  };
})();

exports.default = function () {
  var ref = _asyncToGenerator(function* (text) {
    const emended = text
    // Remove annotations.
    .replace(/(?:\(|（).*?(?:\)|）)/g, '').replace(/(?:\[|［).*?(?:\]|］)/g, '').replace(/〔.*?〕/g, '')

    // Replace substitutions of repeat marks with their unicode characters.
    .replace(/／〃＼/g, '〲').replace(/＼〃／/g, '〲').replace(/／＼/g, '〱').replace(/＼／/g, '〱')

    // Replace some half-width signs with their full-width ones.
    .replace(/｢/g, '「').replace(/｣/g, '」')

    // Remove corner brackets to make a question sentence look nice.
    .replace(/「/g, '').replace(/」/g, '').replace(/『/g, '').replace(/』/g, '');

    // Separate each words with a half-width space
    // to enable QuizGenerator to determine word boundaries easily.
    const wakachigaki = yield wakatsu(emended);

    return wakachigaki;
  });

  return function (_x2) {
    return ref.apply(this, arguments);
  };
}();
//# sourceMappingURL=classical-japanese.js.map